<?php

/**
 * @file
 * Defines and processes a base CollectiveAccess item
 */

class CollectiveAccessBaseItem {
  protected $data;
  protected $collectiveaccess_instance;
  protected $options;
  protected $id;

  /**
   * Create a new CollectiveAccessBaseItem
   * @param CollectiveAccessInstance $ca - object connecting to CollectiveAccess installation
   * @param int $id - id of ca_entities to retrieve
   * @param array $options - array with options
   */
  public function __construct(CollectiveAccessInstance $ca, $id, $options = array()) {
    $this->collectiveaccess_instance = $ca;
    $this->id = $id;
    $this->options = $options;
  }

  /**
   * Magic method to retrieve CollectiveAccess entity attribute
   */
  public function __get($name) {
    if (array_key_exists($name, $this->data)) {
      return $this->data[$name];
    }
  }

  /**
   * Magic method to set CollectiveAccess entity attribute
   */
  public function __set($name, $value) {
    $this->data[$name] = $value;
  }

  /**
   * Get all CollectiveAccess data as a raw array
   * @return array list of attribute data
   */
  public function getData() {
    return $this->data;
  }

  /**
   * Get a list of available attribute keys
   */
  public function getAttributes() {
    if (is_array($this->data)) {
      return array_keys($this->data);
    }
    return FALSE;
  }

  /**
   * Get the CollectiveAccessInstance object
   */
  public function getCAInstance() {
    return $this->collectiveaccess_instance;
  }

  protected function manipulate_attribute($key, $val, $type) {
    // allow other modules to manipulate the value
    drupal_alter('collectiveaccess_attribute', $val, $key, $type);
    // fetch list item labels if requested
    if ($val && $type == "List" && isset($this->options['list_labels']) && $this->options['list_labels'] == TRUE) {
      foreach ($val as $locale => $values) {
        foreach ($values as $k => $v) {
          $data = $v[$key];
          $data_arr = split(':', $data);
          if (is_numeric($data_arr[0])) {
            $options = array('skeleton' => TRUE);
            $ca_list_item = new CollectiveAccessListItem($this->getCAInstance(), $data_arr[0], $options);
            $labels = $ca_list_item->getPreferredLabels();
            $val[$locale][$k]['labels'] = $labels;
          }
        }
      }
    }
    return $val;
  }
}